@@ -1,6 +1,8 @@
 
 from functools import cached_property
 
+from miniweb.exceptions import PayloadTooLarge
+
 from .request import HttpRequest
 from .response import HttpResponse
 from .router import Router
@@ -30,8 +32,11 @@ class Application(object):
             if not handler:
                 http_response.not_found()
             else:
-                handler(http_request, http_response)
-                
+                try:
+                    handler(http_request, http_response)
+                except PayloadTooLarge as error:
+                    http_response.payload_too_large(error.args[0], error.args[1])
+
     def __call__(self, env, start_response):
         request = HttpRequest(env)
         response = HttpResponse(start_response, request=request, application=self)
